summaryrefslogtreecommitdiff
path: root/gtk/gtktextutil.c
diff options
context:
space:
mode:
authorBenjamin Otte <otte@redhat.com>2020-07-24 20:40:36 +0200
committerBenjamin Otte <otte@redhat.com>2020-07-25 00:47:36 +0200
commitd375dce9f52fd9830069a6fd9287abde93d3f24b (patch)
treecd759ec130e07189ab7f19ebd03b8e89923aaa7f /gtk/gtktextutil.c
parentd7266b25ba5f2f21a5bd19d0fb88aca530e4d265 (diff)
downloadgtk+-d375dce9f52fd9830069a6fd9287abde93d3f24b.tar.gz
Replace "gchar" with "char"
Diffstat (limited to 'gtk/gtktextutil.c')
-rw-r--r--gtk/gtktextutil.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/gtk/gtktextutil.c b/gtk/gtktextutil.c
index 56e43d5a39..6110046084 100644
--- a/gtk/gtktextutil.c
+++ b/gtk/gtktextutil.c
@@ -44,7 +44,7 @@
#define ELLIPSIS_CHARACTER "\xe2\x80\xa6"
static void
-append_n_lines (GString *str, const gchar *text, GSList *lines, int n_lines)
+append_n_lines (GString *str, const char *text, GSList *lines, int n_lines)
{
PangoLayoutLine *line;
int i;
@@ -60,7 +60,7 @@ append_n_lines (GString *str, const gchar *text, GSList *lines, int n_lines)
static void
limit_layout_lines (PangoLayout *layout)
{
- const gchar *text;
+ const char *text;
GString *str;
GSList *lines, *elem;
int n_lines;
@@ -93,7 +93,7 @@ limit_layout_lines (PangoLayout *layout)
/**
* gtk_text_util_create_drag_icon:
* @widget: #GtkWidget to extract the pango context
* @text: a #gchar to render the icon
* @len: length of @text, or -1 for NUL-terminated text
*
* Creates a drag and drop icon from @text.
@@ -102,7 +102,7 @@ limit_layout_lines (PangoLayout *layout)
*/
GdkPaintable *
gtk_text_util_create_drag_icon (GtkWidget *widget,
- gchar *text,
+ char *text,
gssize len)
{
GtkCssStyle *style;
@@ -301,7 +301,7 @@ _gtk_text_util_get_block_cursor_location (PangoLayout *layout,
PangoLayoutLine *layout_line;
gboolean rtl;
int line_no;
- const gchar *text;
+ const char *text;
g_return_val_if_fail (layout != NULL, FALSE);
g_return_val_if_fail (index >= 0, FALSE);
@@ -365,7 +365,7 @@ _gtk_text_util_get_block_cursor_location (PangoLayout *layout,
PangoRectangle line_rect;
int i;
int left, right;
- const gchar *p;
+ const char *p;
p = g_utf8_prev_char (text + index);
@@ -93,7 +93,7 @@ limit_layout_lines (PangoLayout *layout)
* gtk_text_util_create_drag_icon:
* @widget: #GtkWidget to extract the pango context
- * @text: a #gchar to render the icon
+ * @text: a #char to render the icon
* @len: length of @text, or -1 for NUL-terminated text
*